@@ -1,5 +1,10 @@
 #! /usr/bin/env python
 
+# set proper application name for being allowed to play sound in silent mode
+import dl
+libc = dl.open("/lib/libc.so.6")
+libc.call("prctl", 15, "FMRadio\0", 0, 0, 0)
+
 from com import Container
 from utils import logging
 import values
