@@ -13,6 +13,7 @@ from ui.decorators import Gestures
 from StationItem import StationItem
 from FMScala import FMScala
 from FMRadio import *
+import rdsdecode
 from SoundPipe import SoundPipe
 import platforms
 import values
@@ -654,6 +655,8 @@ class FMRadioUI(Component, Window):
             pi, ps, rt = self.__radio.get_rds()
             ps = ps.strip() or ""
             rt = rt.strip() or ""
+            ps = rdsdecode.decode(ps).encode("utf-8")
+            rt = rdsdecode.decode(rt).encode("utf-8")
             
             if (ps):
                 self.__lbl_station.set_text(ps)
